You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@uima.apache.org by pk...@apache.org on 2013/04/29 15:45:28 UTC

svn commit: r1477070 - /uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/

Author: pkluegl
Date: Mon Apr 29 13:45:28 2013
New Revision: 1477070

URL: http://svn.apache.org/r1477070
Log:
UIMA-2850
- renaming

Modified:
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxGreedy.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxReluctant.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/NormalQuantifier.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusGreedy.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusReluctant.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionGreedy.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionReluctant.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/RuleElementQuantifier.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarGreedy.java
    uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarReluctant.java

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxGreedy.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxGreedy.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxGreedy.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxGreedy.java Mon Apr 29 13:45:28 2013
@@ -17,21 +17,21 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.expression.number.NumberExpression;
-import org.apache.uima.textmarker.expression.number.SimpleNumberExpression;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.expression.number.NumberExpression;
+import org.apache.uima.ruta.expression.number.SimpleNumberExpression;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class MinMaxGreedy implements RuleElementQuantifier {
 
@@ -54,7 +54,7 @@ public class MinMaxGreedy implements Rul
   }
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     int minValue = min.getIntegerValue(element.getParent());
     int maxValue = max.getIntegerValue(element.getParent());
 
@@ -85,7 +85,7 @@ public class MinMaxGreedy implements Rul
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
           RuleMatch extendedMatch, ComposedRuleElementMatch containerMatch,
-          TextMarkerStream stream, InferenceCrowd crowd) {
+          RutaStream stream, InferenceCrowd crowd) {
     int minValue = min.getIntegerValue(ruleElement.getParent());
     int maxValue = max.getIntegerValue(ruleElement.getParent());
     List<RuleElementMatch> list = containerMatch.getInnerMatches().get(ruleElement);
@@ -106,7 +106,7 @@ public class MinMaxGreedy implements Rul
             || (!lastMatch.matched() && matchedSize >= minValue && matchedSize <= maxValue);
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     int minValue = min.getIntegerValue(parent);
     return minValue == 0;
   }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxReluctant.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxReluctant.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxReluctant.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/MinMaxReluctant.java Mon Apr 29 13:45:28 2013
@@ -17,21 +17,21 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.expression.number.NumberExpression;
-import org.apache.uima.textmarker.expression.number.SimpleNumberExpression;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.expression.number.NumberExpression;
+import org.apache.uima.ruta.expression.number.SimpleNumberExpression;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class MinMaxReluctant implements RuleElementQuantifier {
 
@@ -62,7 +62,7 @@ public class MinMaxReluctant implements 
   }
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     int minValue = min.getIntegerValue(element.getParent());
     int maxValue = max.getIntegerValue(element.getParent());
     if (matches.size() > 0) {
@@ -81,7 +81,7 @@ public class MinMaxReluctant implements 
   }
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
-          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, TextMarkerStream stream,
+          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, RutaStream stream,
           InferenceCrowd crowd) {
     int minValue = min.getIntegerValue(ruleElement.getParent());
     int maxValue = max.getIntegerValue(ruleElement.getParent());
@@ -116,7 +116,7 @@ public class MinMaxReluctant implements 
             || (!lastMatch.matched() && matchedSize >= minValue && matchedSize <= maxValue && !nextMatched);
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     int minValue = min.getIntegerValue(parent);
     return minValue == 0;
   }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/NormalQuantifier.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/NormalQuantifier.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusGreedy.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusGreedy.java Mon Apr 29 13:45:28 2013
@@ -17,19 +17,19 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class PlusGreedy implements RuleElementQuantifier {
 
@@ -38,7 +38,7 @@ public class PlusGreedy implements RuleE
   }
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     boolean result = true;
     boolean allEmpty = true;
     if (matches == null) {
@@ -64,7 +64,7 @@ public class PlusGreedy implements RuleE
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
           RuleMatch extendedMatch, ComposedRuleElementMatch containerMatch,
-          TextMarkerStream stream, InferenceCrowd crowd) {
+          RutaStream stream, InferenceCrowd crowd) {
     List<List<RuleElementMatch>> matchInfo = extendedMatch.getMatchInfo(ruleElement);
     List<RuleElementMatch> matches;
     if (after) {
@@ -93,7 +93,7 @@ public class PlusGreedy implements RuleE
 
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     return false;
   }
 }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusReluctant.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusReluctant.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusReluctant.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusReluctant.java Mon Apr 29 13:45:28 2013
@@ -17,24 +17,24 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class PlusReluctant implements RuleElementQuantifier {
  
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     boolean result = true;
     boolean allEmpty = true;
     for (RuleElementMatch match : matches) {
@@ -56,7 +56,7 @@ public class PlusReluctant implements Ru
   }
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
-          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, TextMarkerStream stream,
+          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, RutaStream stream,
           InferenceCrowd crowd) {
     List<RuleElementMatch> ownList = containerMatch.getInnerMatches().get(ruleElement);
     if (ownList == null || ownList.isEmpty()) {
@@ -75,7 +75,7 @@ public class PlusReluctant implements Ru
     return nextList == null || nextList.isEmpty();
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     return false;
   }
 }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionGreedy.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionGreedy.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionGreedy.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionGreedy.java Mon Apr 29 13:45:28 2013
@@ -17,25 +17,25 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.Collections;
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class QuestionGreedy implements RuleElementQuantifier {
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     boolean result = true;
     if (matches == null) {
       return Collections.emptyList();
@@ -57,12 +57,12 @@ public class QuestionGreedy implements R
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
           RuleMatch extendedMatch, ComposedRuleElementMatch containerMatch,
-          TextMarkerStream stream, InferenceCrowd crowd) {
+          RutaStream stream, InferenceCrowd crowd) {
     List<RuleElementMatch> list = containerMatch.getInnerMatches().get(ruleElement);
     return list == null || list.isEmpty();
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     return true;
   }
 }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionReluctant.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionReluctant.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionReluctant.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/QuestionReluctant.java Mon Apr 29 13:45:28 2013
@@ -17,24 +17,24 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class QuestionReluctant implements RuleElementQuantifier {
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     boolean result = true;
     for (RuleElementMatch match : matches) {
       result &= match.matched() || match.getTextsMatched().isEmpty();
@@ -51,7 +51,7 @@ public class QuestionReluctant implement
   }
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
-          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, TextMarkerStream stream,
+          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, RutaStream stream,
           InferenceCrowd crowd) {
     List<RuleElementMatch> ownList = containerMatch.getInnerMatches().get(ruleElement);
     if (ownList != null && !ownList.isEmpty()) {
@@ -70,7 +70,7 @@ public class QuestionReluctant implement
     return nextList == null || nextList.isEmpty();
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     return true;
   }
 }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/RuleElementQuantifier.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/RuleElementQuantifier.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/RuleElementQuantifier.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/RuleElementQuantifier.java Mon Apr 29 13:45:28 2013
@@ -17,28 +17,28 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public interface RuleElementQuantifier {
 
   List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd);
+          RutaStatement element, InferenceCrowd crowd);
 
   boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
-          RuleMatch extendedMatch, ComposedRuleElementMatch containerMatch, TextMarkerStream stream, InferenceCrowd crowd);
+          RuleMatch extendedMatch, ComposedRuleElementMatch containerMatch, RutaStream stream, InferenceCrowd crowd);
 
-  boolean isOptional(TextMarkerBlock parent);
+  boolean isOptional(RutaBlock parent);
 
 }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarGreedy.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarGreedy.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarGreedy.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarGreedy.java Mon Apr 29 13:45:28 2013
@@ -17,19 +17,19 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class StarGreedy implements RuleElementQuantifier {
 
@@ -38,7 +38,7 @@ public class StarGreedy implements RuleE
   }
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     boolean result = true;
     if (matches == null) {
       return null;
@@ -60,11 +60,11 @@ public class StarGreedy implements RuleE
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
           RuleMatch extendedMatch, ComposedRuleElementMatch containerMatch,
-          TextMarkerStream stream, InferenceCrowd crowd) {
+          RutaStream stream, InferenceCrowd crowd) {
     return true;
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     return true;
   }
 }

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarReluctant.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarReluctant.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarReluctant.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/StarReluctant.java Mon Apr 29 13:45:28 2013
@@ -17,29 +17,29 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class StarReluctant implements RuleElementQuantifier {
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     return matches;
   }
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
-          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, TextMarkerStream stream,
+          RuleMatch ruleMatch, ComposedRuleElementMatch containerMatch, RutaStream stream,
           InferenceCrowd crowd) {
     RuleElement nextElement = ruleElement.getContainer().getNextElement(after, ruleElement);
     if (nextElement == null) {
@@ -53,7 +53,7 @@ public class StarReluctant implements Ru
     return nextList == null || nextList.isEmpty();
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     return true;
   }
 }
--- uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/NormalQuantifier.java (original)
+++ uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/NormalQuantifier.java Mon Apr 29 13:45:28 2013
@@ -17,30 +17,30 @@
  * under the License.
  */
 
-package org.apache.uima.textmarker.rule.quantifier;
+package org.apache.uima.ruta.rule.quantifier;
 
 import java.util.List;
 
 import org.apache.uima.cas.text.AnnotationFS;
-import org.apache.uima.textmarker.TextMarkerBlock;
-import org.apache.uima.textmarker.TextMarkerStatement;
-import org.apache.uima.textmarker.TextMarkerStream;
-import org.apache.uima.textmarker.rule.ComposedRuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleElement;
-import org.apache.uima.textmarker.rule.RuleElementMatch;
-import org.apache.uima.textmarker.rule.RuleMatch;
-import org.apache.uima.textmarker.visitor.InferenceCrowd;
+import org.apache.uima.ruta.RutaBlock;
+import org.apache.uima.ruta.RutaStatement;
+import org.apache.uima.ruta.RutaStream;
+import org.apache.uima.ruta.rule.ComposedRuleElementMatch;
+import org.apache.uima.ruta.rule.RuleElement;
+import org.apache.uima.ruta.rule.RuleElementMatch;
+import org.apache.uima.ruta.rule.RuleMatch;
+import org.apache.uima.ruta.visitor.InferenceCrowd;
 
 public class NormalQuantifier implements RuleElementQuantifier {
   // @Override
   // public boolean continueMatch(int index, List<RuleElement> elements, TextMarkerBasic next,
   // RuleElementMatch match, List<RuleElementMatch> matches, TextMarkerStream stream,
   // InferenceCrowd crowd) {
   // return match == null;
   // }
 
   public List<RuleElementMatch> evaluateMatches(List<RuleElementMatch> matches,
-          TextMarkerStatement element, InferenceCrowd crowd) {
+          RutaStatement element, InferenceCrowd crowd) {
     if (matches == null) {
       return null;
     }
@@ -60,12 +60,12 @@ public class NormalQuantifier implements
 
   public boolean continueMatch(boolean after, AnnotationFS annotation, RuleElement ruleElement,
           RuleMatch extendedMatch, ComposedRuleElementMatch containerMatch,
-          TextMarkerStream stream, InferenceCrowd crowd) {
+          RutaStream stream, InferenceCrowd crowd) {
     List<RuleElementMatch> list = containerMatch.getInnerMatches().get(ruleElement);
     return list == null || list.isEmpty();
   }
 
-  public boolean isOptional(TextMarkerBlock parent) {
+  public boolean isOptional(RutaBlock parent) {
     return false;
   }
 }
@@ -17,30 +17,30 @@
 public class NormalQuantifier implements RuleElementQuantifier {
   // @Override
-  // public boolean continueMatch(int index, List<RuleElement> elements, TextMarkerBasic next,
-  // RuleElementMatch match, List<RuleElementMatch> matches, TextMarkerStream stream,
+  // public boolean continueMatch(int index, List<RuleElement> elements, RutaBasic next,
+  // RuleElementMatch match, List<RuleElementMatch> matches, RutaStream stream,
   // InferenceCrowd crowd) {
   // return match == null;

Modified: uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusGreedy.java
URL: http://svn.apache.org/viewvc/uima/sandbox/ruta/trunk/ruta-core/src/main/java/org/apache/uima/ruta/rule/quantifier/PlusGreedy.java?rev=1477070&r1=1477069&r2=1477070&view=diff
==============================================================================